## besio
::: pybes3.open
---
::: pybes3.concatenate
---
::: pybes3.open_raw
---
::: pybes3.concatenate_raw
---

## detectors
::: pybes3.emc_barrel_h1
---
::: pybes3.emc_barrel_h2
---
::: pybes3.emc_barrel_h3
---
::: pybes3.emc_barrel_l
---
::: pybes3.emc_barrel_offset_1
---
::: pybes3.emc_barrel_offset_2
---
::: pybes3.emc_barrel_r
---
::: pybes3.emc_gid_to_center_x
---
::: pybes3.emc_gid_to_center_y
---
::: pybes3.emc_gid_to_center_z
---
::: pybes3.emc_gid_to_front_center_x
---
::: pybes3.emc_gid_to_front_center_y
---
::: pybes3.emc_gid_to_front_center_z
---
::: pybes3.emc_gid_to_part
---
::: pybes3.emc_gid_to_phi
---
::: pybes3.emc_gid_to_point_x
---
::: pybes3.emc_gid_to_point_y
---
::: pybes3.emc_gid_to_point_z
---
::: pybes3.emc_gid_to_theta
---
::: pybes3.get_emc_crystal_position
---
::: pybes3.get_emc_gid
---
::: pybes3.get_mdc_gid
---
::: pybes3.get_mdc_wire_position
---
::: pybes3.mdc_gid_to_east_x
---
::: pybes3.mdc_gid_to_east_y
---
::: pybes3.mdc_gid_to_east_z
---
::: pybes3.mdc_gid_to_is_stereo
---
::: pybes3.mdc_gid_to_layer
---
::: pybes3.mdc_gid_to_stereo
---
::: pybes3.mdc_gid_to_superlayer
---
::: pybes3.mdc_gid_to_west_x
---
::: pybes3.mdc_gid_to_west_y
---
::: pybes3.mdc_gid_to_west_z
---
::: pybes3.mdc_gid_to_wire
---
::: pybes3.mdc_gid_z_to_x
---
::: pybes3.mdc_gid_z_to_y
---
::: pybes3.mdc_layer_to_is_stereo
---
::: pybes3.mdc_layer_to_superlayer
---
::: pybes3.parse_cgem_digi_id
---
::: pybes3.parse_emc_digi
---
::: pybes3.parse_emc_digi_id
---
::: pybes3.parse_emc_gid
---
::: pybes3.parse_mdc_digi
---
::: pybes3.parse_mdc_digi_id
---
::: pybes3.parse_mdc_gid
---
::: pybes3.parse_muc_digi_id
---
::: pybes3.parse_tof_digi_id
---

## tracks
::: pybes3.HelixObject
---
::: pybes3.dr_phi0_to_x
---
::: pybes3.dr_phi0_to_y
---
::: pybes3.helix_awk
---
::: pybes3.helix_obj
---
::: pybes3.kappa_to_charge
---
::: pybes3.kappa_to_pt
---
::: pybes3.kappa_to_radius
---
::: pybes3.phi0_to_phi
---
